API documentation
=================

opendaq.daq module
------------------
Main functions used to communicate with the device.
See ``usage.rst`` for additional info.

.. automodule:: opendaq.daq
    :members:
    :undoc-members:
    :show-inheritance:

Experiment classes
^^^^^^^^^^^^^^^^^^

.. automodule:: opendaq.experiment
    :members:
    :undoc-members:
    :show-inheritance:
